
time <- seq(0, 100, by = 0.5)
data <- cbind(time, 20 * sin(time), rep(1, length(time)))

test.knew <- function() {
	k <- knew()
	checkEquals(class(k), "kernel")
}

test.kadd_data <- function() {
	k <- knew()
	kadd_data(k, data)
	checkEquals(nrow(data), nrow(kdata(k)))
}

test.kremove_data <- function() {
	k <- knew()
	kadd_data(k, data)	
	kremove_data(k, -1)
	checkEquals(knsets(k), 0)
	kadd_data(k, data)
	checkEquals(knsets(k), 1)
}

test.kadd <- function() {
	k <- knew()
	kadd(k, period = 1e4, mass = 1.5)
	
	checkEqualsNumeric(period(k, 1), 1e4)
	checkEqualsNumeric(mass(k, 1), 1.5)
	
	kadd(k, period = 300, ma = 10, ecc = 0.6, lop = 25)
	checkEqualsNumeric(period(k, 1), 1e4)
	checkEqualsNumeric(period(k, 2), 300)
	checkEqualsNumeric(ma(k, 2), 10)
	checkEqualsNumeric(ecc(k, 2), 0.6)
	checkEqualsNumeric(lop(k, 2), 25)
}

test.kremove <- function() {
	k <- knew()
	kadd(k, period = 1000)
	kadd(k, period = 365)
	
	kremove(k, 1)
	checkEqualsNumeric(period(k, 1), 365)
	
	kadd(k, period = 2500)
	kremove(k, 2)
	checkEqualsNumeric(period(k, 1), 365)
}

test.kels <- function() {
	k <- knew()
	P <- rnorm(2, mean = 1e4, sd = 100)
	kadd(k, period = P[1])
	kadd(k, period = P[2])
	
	els <- kels(k)
	checkEqualsNumeric(els[1, 1], P[1])
	checkEqualsNumeric(els[2, 1], P[2])	
	
	kels(k) <- els
	checkEqualsNumeric(els, kels(k))
}

test.kdata <- function() {
	k <- knew()
	
	kadd_data(k, data)
	l <- kdata(k)
	
	checkEquals(nrow(l), nrow(data))
	checkEquals(ncol(l), DATA_SIZE)
	
	r <- runif(1)
	l[1, VAL] <- r
	kdata(k, 1) <- l
	
	checkEquals(nrow(l), nrow(kdata(k)))
	checkEqualsNumeric(kdata(k)[1, VAL], r)
}